@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class DefaultTargetCapacityType
-  {
-    NOT_SET,
-    spot,
-    on_demand,
-    capacity_block
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class DefaultTargetCapacityType { NOT_SET, spot, on_demand, capacity_block };
 
-namespace DefaultTargetCapacityTypeMapper
-{
+namespace DefaultTargetCapacityTypeMapper {
 AWS_EC2_API DefaultTargetCapacityType GetDefaultTargetCapacityTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForDefaultTargetCapacityType(DefaultTargetCapacityType value);
-} // namespace DefaultTargetCapacityTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace DefaultTargetCapacityTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
