@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class EphemeralNvmeSupport
-  {
-    NOT_SET,
-    unsupported,
-    supported,
-    required
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class EphemeralNvmeSupport { NOT_SET, unsupported, supported, required };
 
-namespace EphemeralNvmeSupportMapper
-{
+namespace EphemeralNvmeSupportMapper {
 AWS_EC2_API EphemeralNvmeSupport GetEphemeralNvmeSupportForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForEphemeralNvmeSupport(EphemeralNvmeSupport value);
-} // namespace EphemeralNvmeSupportMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace EphemeralNvmeSupportMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
