@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class InstanceGeneration
-  {
-    NOT_SET,
-    current,
-    previous
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class InstanceGeneration { NOT_SET, current, previous };
 
-namespace InstanceGenerationMapper
-{
+namespace InstanceGenerationMapper {
 AWS_EC2_API InstanceGeneration GetInstanceGenerationForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForInstanceGeneration(InstanceGeneration value);
-} // namespace InstanceGenerationMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace InstanceGenerationMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
