@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class IpamDiscoveryFailureCode
-  {
-    NOT_SET,
-    assume_role_failure,
-    throttling_failure,
-    unauthorized_failure
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class IpamDiscoveryFailureCode { NOT_SET, assume_role_failure, throttling_failure, unauthorized_failure };
 
-namespace IpamDiscoveryFailureCodeMapper
-{
+namespace IpamDiscoveryFailureCodeMapper {
 AWS_EC2_API IpamDiscoveryFailureCode GetIpamDiscoveryFailureCodeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForIpamDiscoveryFailureCode(IpamDiscoveryFailureCode value);
-} // namespace IpamDiscoveryFailureCodeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace IpamDiscoveryFailureCodeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
