@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class OutputFormat
-  {
-    NOT_SET,
-    csv,
-    parquet
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class OutputFormat { NOT_SET, csv, parquet };
 
-namespace OutputFormatMapper
-{
+namespace OutputFormatMapper {
 AWS_EC2_API OutputFormat GetOutputFormatForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForOutputFormat(OutputFormat value);
-} // namespace OutputFormatMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace OutputFormatMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
