@@ -4,30 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ServiceLinkVirtualInterfaceConfigurationState
-  {
-    NOT_SET,
-    pending,
-    available,
-    deleting,
-    deleted
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ServiceLinkVirtualInterfaceConfigurationState { NOT_SET, pending, available, deleting, deleted };
 
-namespace ServiceLinkVirtualInterfaceConfigurationStateMapper
-{
+namespace ServiceLinkVirtualInterfaceConfigurationStateMapper {
 AWS_EC2_API ServiceLinkVirtualInterfaceConfigurationState GetServiceLinkVirtualInterfaceConfigurationStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForServiceLinkVirtualInterfaceConfigurationState(ServiceLinkVirtualInterfaceConfigurationState value);
-} // namespace ServiceLinkVirtualInterfaceConfigurationStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ServiceLinkVirtualInterfaceConfigurationStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
