@@ -4,33 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class WeekDay
-  {
-    NOT_SET,
-    sunday,
-    monday,
-    tuesday,
-    wednesday,
-    thursday,
-    friday,
-    saturday
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class WeekDay { NOT_SET, sunday, monday, tuesday, wednesday, thursday, friday, saturday };
 
-namespace WeekDayMapper
-{
+namespace WeekDayMapper {
 AWS_EC2_API WeekDay GetWeekDayForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForWeekDay(WeekDay value);
-} // namespace WeekDayMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace WeekDayMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
